@@ -3,6 +3,7 @@ import logging
 from leap.common import certs
 from leap.common import check
 from leap.common import files
+from leap.common import events
 
 logger = logging.getLogger(__name__)
 
@@ -10,9 +11,9 @@ try:
     import pygeoip
     HAS_GEOIP = True
 except ImportError:
-    logger.debug('PyGeoIP not found. Disabled Geo support.')
+    #logger.debug('PyGeoIP not found. Disabled Geo support.')
     HAS_GEOIP = False
 
-__all__ = ["certs", "check", "files"]
+__all__ = ["certs", "check", "files", "events"]
 
-__version__ = "0.2.0-dev"
+__version__ = "0.2.1-dev"
